RelayServiceConfig

Struct RelayServiceConfig 

pub struct RelayServiceConfig {
    pub password: String,
    pub network_interfaces_to_allow: Vec<String>,
    pub network_interfaces_to_ignore: Vec<String>,
    pub streamer_urls: Vec<String>,
    pub interface_name_overrides: Vec<String>,
    pub runtime_status_file: Option<PathBuf>,
    pub database: PathBuf,
}
Configuration for a RelayService.

Fields

password: Stringnetwork_interfaces_to_allow: Vec<String>

Regex of interface names to allow (^/$ anchors added automatically).

network_interfaces_to_ignore: Vec<String>

Regex of interface names to ignore (^/$ anchors added automatically).

streamer_urls: Vec<String>

Streamer URLs to connect to directly instead of discovering over mDNS.

interface_name_overrides: Vec<String>

"interface=label" pairs renaming a relay as shown in the Moblin app.

runtime_status_file: Option<PathBuf>

File to write relay/streamer state as JSON for external UIs to read.

database: PathBuf

File storing the per-interface relay identities.